summaryrefslogtreecommitdiff
path: root/worker/tests/https.rb
diff options
context:
space:
mode:
authorSteve Kemp <steve@steve.org.uk>2012-11-13 13:08:35 +0000
committerSteve Kemp <steve@steve.org.uk>2012-11-13 13:08:35 +0000
commitab876665a2cf25b1bf557ea7d6cd9ff7e7923db6 (patch)
tree6b6affb2de6d84f3935a5cf5d6b2ce59f846830e /worker/tests/https.rb
parent37b701fc0c7002e2d84f2d61bd9c57085c8b9542 (diff)
Renamed 'get_details()' to 'error()'.
Diffstat (limited to 'worker/tests/https.rb')
-rwxr-xr-xworker/tests/https.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/worker/tests/https.rb b/worker/tests/https.rb
index f487b1d..77739d1 100755
--- a/worker/tests/https.rb
+++ b/worker/tests/https.rb
@@ -36,7 +36,7 @@ class HTTPSTest
#
# Return "false" on failure.
#
# If the test fails the details should be retrieved from "get_details".
#
def run_test
@@ -92,7 +92,7 @@ class HTTPSTest
#
# Return the error text for why this test failed.
#
- def get_details
+ def error
return @error
end
@@ -172,7 +172,7 @@ if __FILE__ == $0 then
puts "TEST OK"
else
puts "TEST FAILED"
- puts http.get_details()
+ puts http.error()
end
end
@@ -36,7 +36,7 @@ class HTTPSTest
# Return "false" on failure.
#
- # If the test fails the details should be retrieved from "get_details".
+ # If the test fails the details should be retrieved from "error()".
#
def run_test